@@ -1,41 +1,48 @@
-/*===========================================================================*\
+/* ========================================================================= *
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
- *                           www.openmesh.org                                *
+ *           Copyright (c) 2001-2015, RWTH-Aachen University                 *
+ *           Department of Computer Graphics and Multimedia                  *
+ *                          All rights reserved.                             *
+ *                            www.openmesh.org                               *
  *                                                                           *
- *---------------------------------------------------------------------------* 
- *  This file is part of OpenMesh.                                           *
+ *---------------------------------------------------------------------------*
+ * This file is part of OpenMesh.                                            *
+ *---------------------------------------------------------------------------*
  *                                                                           *
- *  OpenMesh is free software: you can redistribute it and/or modify         * 
- *  it under the terms of the GNU Lesser General Public License as           *
- *  published by the Free Software Foundation, either version 3 of           *
- *  the License, or (at your option) any later version with the              *
- *  following exceptions:                                                    *
+ * Redistribution and use in source and binary forms, with or without        *
+ * modification, are permitted provided that the following conditions        *
+ * are met:                                                                  *
  *                                                                           *
- *  If other files instantiate templates or use macros                       *
- *  or inline functions from this file, or you compile this file and         *
- *  link it with other files to produce an executable, this file does        *
- *  not by itself cause the resulting executable to be covered by the        *
- *  GNU Lesser General Public License. This exception does not however       *
- *  invalidate any other reasons why the executable file might be            *
- *  covered by the GNU Lesser General Public License.                        *
+ * 1. Redistributions of source code must retain the above copyright notice, *
+ *    this list of conditions and the following disclaimer.                  *
  *                                                                           *
- *  OpenMesh is distributed in the hope that it will be useful,              *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *  GNU Lesser General Public License for more details.                      *
+ * 2. Redistributions in binary form must reproduce the above copyright      *
+ *    notice, this list of conditions and the following disclaimer in the    *
+ *    documentation and/or other materials provided with the distribution.   *
  *                                                                           *
- *  You should have received a copy of the GNU LesserGeneral Public          *
- *  License along with OpenMesh.  If not,                                    *
- *  see <http://www.gnu.org/licenses/>.                                      *
+ * 3. Neither the name of the copyright holder nor the names of its          *
+ *    contributors may be used to endorse or promote products derived from   *
+ *    this software without specific prior written permission.               *
  *                                                                           *
-\*===========================================================================*/ 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED *
+ * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A           *
+ * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER *
+ * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,  *
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,       *
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR        *
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    *
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING      *
+ * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS        *
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.              *
+ *                                                                           *
+ * ========================================================================= */
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 990 $                                                         *
- *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
+ *   $Revision$                                                         *
+ *   $Date$                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -46,6 +53,7 @@
 #endif
 
 #include <iomanip>
+#include <iostream>
 #include <sstream>
 #include <algorithm>
 // --------------------
@@ -55,12 +63,11 @@
 #  include <GL/glut.h>
 #endif
 // --------------------
-#include <qnamespace.h>
-#include <qapplication.h>
-#include <qmenu.h>
-#include <qcursor.h>
-#include <qimage.h>
-#include <qdatetime.h>
+#include <QApplication>
+#include <QMenu>
+#include <QCursor>
+#include <QImage>
+#include <QDateTime>
 #include <QMouseEvent>
 // --------------------
 #include <OpenMesh/Apps/QtViewer/QGLViewerWidget.hh>
@@ -147,10 +154,10 @@ QGLViewerWidget::~QGLViewerWidget()
 void 
 QGLViewerWidget::setDefaultMaterial(void)
 {
-  GLfloat mat_a[] = {0.1, 0.1, 0.1, 1.0};
-  GLfloat mat_d[] = {0.7, 0.7, 0.5, 1.0};
-  GLfloat mat_s[] = {1.0, 1.0, 1.0, 1.0};
-  GLfloat shine[] = {120.0};
+  GLfloat mat_a[] = {0.1f, 0.1f, 0.1f, 1.0f};
+  GLfloat mat_d[] = {0.7f, 0.7f, 0.5f, 1.0f};
+  GLfloat mat_s[] = {1.0f, 1.0f, 1.0f, 1.0f};
+  GLfloat shine[] = {120.0f};
   
   glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT,   mat_a);
   glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE,   mat_d);
@@ -164,12 +171,12 @@ QGLViewerWidget::setDefaultMaterial(void)
 void
 QGLViewerWidget::setDefaultLight(void)
 {
-  GLfloat pos1[] = { 0.1,  0.1, -0.02, 0.0};
-  GLfloat pos2[] = {-0.1,  0.1, -0.02, 0.0};
-  GLfloat pos3[] = { 0.0,  0.0,  0.1,  0.0};
-  GLfloat col1[] = { 0.7,  0.7,  0.8,  1.0};
-  GLfloat col2[] = { 0.8,  0.7,  0.7,  1.0};
-  GLfloat col3[] = { 1.0,  1.0,  1.0,  1.0};
+  GLfloat pos1[] = { 0.1f,  0.1f, -0.02f, 0.0f};
+  GLfloat pos2[] = {-0.1f,  0.1f, -0.02f, 0.0f};
+  GLfloat pos3[] = { 0.0f,  0.0f,  0.1f,  0.0f};
+  GLfloat col1[] = { 0.7f,  0.7f,  0.8f,  1.0f};
+  GLfloat col2[] = { 0.8f,  0.7f,  0.7f,  1.0f};
+  GLfloat col3[] = { 1.0f,  1.0f,  1.0f,  1.0f};
  
   glEnable(GL_LIGHT0);    
   glLightfv(GL_LIGHT0,GL_POSITION, pos1);
@@ -207,10 +214,10 @@ QGLViewerWidget::initializeGL()
   setDefaultLight();  
   
   // Fog
-  GLfloat fogColor[4] = { 0.3, 0.3, 0.4, 1.0 };
+  GLfloat fogColor[4] = { 0.3f, 0.3f, 0.4f, 1.0f };
   glFogi(GL_FOG_MODE,    GL_LINEAR);
   glFogfv(GL_FOG_COLOR,  fogColor);
-  glFogf(GL_FOG_DENSITY, 0.35);
+  glFogf(GL_FOG_DENSITY, 0.35f);
   glHint(GL_FOG_HINT,    GL_DONT_CARE);
   glFogf(GL_FOG_START,    5.0f);
   glFogf(GL_FOG_END,     25.0f);
