@@ -777,6 +777,11 @@ void PolyConnectivity::collapse_edge(HalfedgeHandle _hh)
   // delete stuff
   status(edge_handle(h)).set_deleted(true);
   status(vo).set_deleted(true);
+  if (has_halfedge_status())
+  {
+    status(h).set_deleted(true);
+    status(o).set_deleted(true);
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -827,6 +832,11 @@ void PolyConnectivity::collapse_loop(HalfedgeHandle _hh)
     status(fh).set_deleted(true);
   }
   status(edge_handle(h0)).set_deleted(true);
+  if (has_halfedge_status())
+  {
+    status(h0).set_deleted(true);
+    status(o0).set_deleted(true);
+  }
 }
 
 //-----------------------------------------------------------------------------
@@ -1032,6 +1042,7 @@ void PolyConnectivity::triangulate(FaceHandle _fh)
 
   HalfedgeHandle base_heh(halfedge_handle(_fh));
   VertexHandle start_vh = from_vertex_handle(base_heh);
+  HalfedgeHandle prev_heh(prev_halfedge_handle(base_heh));
   HalfedgeHandle next_heh(next_halfedge_handle(base_heh));
 
   while (to_vertex_handle(next_halfedge_handle(next_heh)) != start_vh)
@@ -1051,6 +1062,10 @@ void PolyConnectivity::triangulate(FaceHandle _fh)
     set_face_handle(next_heh, new_fh);
     set_face_handle(new_heh,  new_fh);
 
+    copy_all_properties(prev_heh, new_heh, true);
+    copy_all_properties(prev_heh, opposite_halfedge_handle(new_heh), true);
+    copy_all_properties(_fh, new_fh, true);
+
     base_heh = opposite_halfedge_handle(new_heh);
     next_heh = next_next_heh;
   }
@@ -1125,7 +1140,7 @@ void PolyConnectivity::split_copy(FaceHandle fh, VertexHandle vh) {
 
   // Copy the property of the original face to all new faces
   for(VertexFaceIter vf_it =  vf_iter(vh); vf_it.is_valid(); ++vf_it)
-    copy_all_properties(fh, *vf_it);
+    copy_all_properties(fh, *vf_it, true);
 }
 
 //-----------------------------------------------------------------------------
@@ -1221,7 +1236,7 @@ void PolyConnectivity::split_edge_copy(EdgeHandle _eh, VertexHandle _vh)
   EdgeHandle eh0 = edge_handle( next_halfedge_handle( halfedge_handle(_eh, 1) ) );
 
   // Copy the property from the original to the new edge
-  copy_all_properties(_eh, eh0);
+  copy_all_properties(_eh, eh0, true);
 }
 
 } // namespace OpenMesh
